@@ -383,7 +383,7 @@ class DApi2Commands(MetaDApi2Commands):
     
     
     def peripheralActivate(self, value):
-        if value != 0 and self.owner.regs.par.value != 0:
+        if value != 0 and self.owner.regs.par.value != 0 and not self.owner.dev_mode:
             self.standby()
         msg = dmsg.CommandMessage(DApi2Commands.PERIPHERAL_ACTIVATE)
         msg.setWord(value)
