@@ -32,6 +32,16 @@ def getXmlDescription(xelement, lang='en'):
         return xdescr.text
     return None
 
+def getXmlDescriptions(xelement):
+    '''Get all descriptions of XML element.
+    
+    :param xelement: The XML element
+    :type xelement: ElementTree
+    '''
+    ret = {}
+    for xdescr in xelement.findall('descr'):
+        ret[xdescr.get('lang', None)] = xdescr.text
+    return ret
 
 class BaseRegReader(object):
     '''Base class for register structure elements reader
@@ -147,10 +157,12 @@ class RegGroupReader(BaseRegReader):
                         self.parent, 
                         addr, 
                         size=int(xgroup.get('size','0'),0), 
-                        descr=getXmlDescription(xgroup),
+                        descriptions=getXmlDescriptions(xgroup),
                         shortname=xgroup.get('shortname'),
                         readonly=not (int(xgroup.get('write','0')) == 1), 
                     )
+
+                    
         rreg =  RegReader(self, self.element)
         for xreg in xgroup.findall('reg'):
             reg = rreg.readXml(xreg, addr)
@@ -197,7 +209,7 @@ class RegReader(BaseRegReader):
                          self.parent, 
                          addr, 
                          size=size, 
-                         descr=getXmlDescription(xreg),
+                         descriptions=getXmlDescriptions(xreg),
                          shortname=xreg.get('shortname'),
                          readonly=readonly,
                          )
@@ -219,13 +231,13 @@ class BitFieldReader(BaseRegReader):
         size = int(xbit.get('size','1'),0)
         name = xbit.get('name')
         if name is not None:
-            self._element = dreg.RegBit(name, self.parent, addr, size, descr=getXmlDescription(xbit),)
+            self._element = dreg.RegBit(name, self.parent, addr, size, descriptions=getXmlDescriptions(xbit),)
             self._element.choices = {}
 #             for xchoice in xbit.findall('choice'):
 #                 v = int(xchoice.get('value','0'),0)
 #                 self._element.choices[v] = dreg.RegBitChoice(self._element,xchoice.get('name'), v, descr=getXmlDescription(xchoice), shortname=xchoice.get('shortname'))
         else: 
-            self._element = dreg.ReservedRegBit('Reserved', self.parent, addr, size, descr=getXmlDescription(xbit),)
+            self._element = dreg.ReservedRegBit('Reserved', self.parent, addr, size, descriptions=getXmlDescriptions(xbit),)
         return self.element
     
 def newRegContainerFromFile(filename=None):
