@@ -26,8 +26,8 @@ class Register(BaseRegElement):
     :param size: Group size, number of registers slot in group (optional).
     :type size: int
 
-    :param descr: Group  description (otional).
-    :type descr: str
+    :param dict descriptions: Multilingual Element description (otional). 
+           The dictionary key is language code {fr,de,it,...} or None for the default language, by convention the English. 
 
     :param shortname: Group short name (otional).
     :type shortname: str
@@ -37,9 +37,9 @@ class Register(BaseRegElement):
     '''
     
     
-    def __init__(self, name, parent=None, addr=None, size=1, descr=None, shortname=None, min=0, max=REG_MAX_VALUE, readonly=True): #@ReservedAssignment
+    def __init__(self, name, parent=None, addr=None, size=1, descriptions=None, shortname=None, min=0, max=REG_MAX_VALUE, readonly=True): #@ReservedAssignment
         assert parent is None or isinstance(parent, (dreg.RegContainer, dreg.RegGroup, dreg.RegisterArray )), 'parent is '+type(parent).__name__
-        super().__init__(name, parent, addr, size, descr, shortname)
+        super().__init__(name, parent, addr, size, descriptions, shortname)
         self.readonly = readonly
         self.min = min
         self.max = max  
@@ -105,8 +105,8 @@ class ReservedRegister(Register):
         
 class BitFieldRegister(Register):
     
-    def __init__(self, name, parent=None, addr=None, size=1, descr=None, shortname=None, readonly=True):
-        super().__init__(name, parent, addr, size, descr, shortname, readonly)
+    def __init__(self, name, parent=None, addr=None, size=1, descriptions=None, shortname=None, readonly=True):
+        super().__init__(name, parent, addr, size, descriptions, shortname, readonly)
         self._bits = []
         self._index = {}
         
@@ -198,8 +198,8 @@ class BitFieldRegister(Register):
         return self._bits 
         
 class RegisterArray(Register):
-    def __init__(self, name, parent=None, addr=None, size=1, descr=None, shortname=None, readonly=True):
-        super().__init__(name, parent, addr, size, descr, shortname, readonly)
+    def __init__(self, name, parent=None, addr=None, size=1, descriptions=None, shortname=None, readonly=True):
+        super().__init__(name, parent, addr, size, descriptions, shortname, readonly)
         self._regs = []
         
         for i in range(self.size):
@@ -250,11 +250,14 @@ class RegisterArray(Register):
         return list([ self._regs[i].get() for i in range(self.size) ])
 
 class RegBitChoice():
-    def __init__(self, name, value, bit=None, descr=None, shortname=None ):
+    def __init__(self, name, value, bit=None, descriptions=None, shortname=None ):
         self._bit = bit
         self.value = value
         self.name = name
-        self.descr = descr
+        if isinstance(descriptions, dict): 
+            self._descriptions = descriptions
+        else:
+            self._descriptions = {None:descriptions}   
         if shortname is None:
             self.shortname = name[:3]
         else:
@@ -267,12 +270,26 @@ class RegBitChoice():
         return self.value < other.value
     
     def __eq__(self, other):
-        return self.value == other.value        
+        return self.value == other.value    
+    
+    def getDescription(self, lang=None):
+        try:
+            return self._descriptions[lang]
+        except KeyError:
+            return self._descriptions[None]     
+        
+    @property
+    def descriptions(self):
+        return self._descriptions
+    
+    @property
+    def descr(self):
+        return self.getDescription()          
 
 
 class RegBit(BaseRegElement):
-    def __init__(self, name, parent=None, addr=None, size=1, descr=None, shortname=None, choices={}):
-        super().__init__(name, parent, addr, size, descr, shortname)
+    def __init__(self, name, parent=None, addr=None, size=1, descriptions=None, shortname=None, choices={}):
+        super().__init__(name, parent, addr, size, descriptions, shortname)
         self.choices = choices
         if shortname is None:
             self.shortname = name[:3]
