@@ -137,6 +137,8 @@ class BaseDBoard(object):
         '''
         if not isinstance(bit, RegBit):
             bit = self.dapi.getBit(bit)
+        if bit.parent.isUndefined() and not self.dapi.dev_mode:
+            self.dapi.readReg(bit.parent)
         v = bit.set(value) 
         bit.parent.alter( v )
         if synchronous:
