@@ -56,6 +56,9 @@ class DBoardFactory(object):
                             callback_msg('The attempt to read is failed')
                     self.dapi.log.error('The attempt to read is failed')
             
+        if self.dapi.comm is None:
+            return None
+        
         _firstCom()
         
         
